.. _spider_wienerlinien.at:

wienerlinien.at
---------------
Get newest articles from `Wiener Linien <https://wienerlinien.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``wienerlinien.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     wienerlinien.at

